trainer.MqConn
==============

.. currentmodule:: trainer

.. autoclass:: MqConn

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~MqConn.__init__
      ~MqConn.close
      ~MqConn.delete_queue
      ~MqConn.pull
      ~MqConn.push
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~MqConn.host
      ~MqConn.password
      ~MqConn.port
      ~MqConn.user
      ~MqConn.virtualHost
   
   